RDFCalendar

Package RDFCalendar |
[show private | hide private]
[frames | no frames]

## Package RDFCalendar

    Conversion of iCalendar/vCard resources to RDF information.

    Copyright (C) 2005, 2006, 2007 Paul Boddie <paul@boddie.org.uk>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

Submodules
`Format`: Constants for parsing and writing. `FormatWriters`: Format writer classes. `Parsers`: Conversion of iCalendar files to and from RDF representations. `Store`: Storage of nodes according to RDFCalendar conventions. `Writers`: Writer classes.

Variable Summary
`str` | `__version__` = `'0.2.2'`

Variable Details

    ### __version__ Type: `str` Value:
        '0.2.2'

Generated by Epydoc 2.1 on Mon Mar 19 01:08:11 2007 | http://epydoc.sf.net